#!/bin/sh

#Global constant declarations
FLAG_FILE=/instrumentData/FlashPartitionFormatV2


############################ Repartition flash ##################################
#
# Repartition the flash so that /instrumentData, /log and /extendedLog are put 
# together in a single partition /instrumentData
#
#################################################################################
flashrepartition () {
	
	retVal=0
	
	
	#echo "Debugging flashing failure"
	#return -1
	
	#check if flash is already formatted in v2 format.
	 if [ -e "$FLAG_FILE" ]
	 then
		echo "$FLAG_FILE found, Partitions /log,/extendlog and /instrumentData already combined into a single partition /instrumentData"
		return $retVal
	fi
	
	echo "$FLAG_FILE not found"
	
	
	if ! [ -e /instrumentData ] && ! [ -e /extendedLog ]
	then
		echo "/instrumentData and /extendedLog are not found, repartition not needed (prodSw partition assumed)"
		return $retVal
	fi

	
	#old(v1) flash format with separate /instrumentData,/log,/extendedLog partitions
	echo "Need to combine the partitions /log, /extendedLog and /instrumentData into a single partition /instrumentData"

	#create 2M partition at the previous /app
	echo "Create /tmpInstrumentData"
	flashctl -p /dev/fs1p1 -o 0 -l 2M -e -f -n /tmpInstrumentData -m > /dev/null
	slay -f devf-s3c2400-p3
	devf-s3c2400-p3 -r -u2 -b5 -i 1,0
	waitfor /dev/fs1

	#copy old files into tmpInstrumentData
	echo "backup /instrumentData /log /extendedLog"
	cp -R /instrumentData/* /log/* /extendedLog/* /tmpInstrumentData > /dev/null
   
	#create instrumentdata partition
	echo "delete old partitions, /instrumentData, /log, /extendedLog"
	flashctl -p /dev/fs1 -o 12M -l 4M -e > /dev/null
	slay -f devf-s3c2400-p3
	devf-s3c2400-p3 -r -u2 -b5 -i 1,0
	waitfor /dev/fs1

	echo "create new /instrumentData"
	flashctl -p /dev/fs1p2 -o 6M -l 4M -e -f -n /instrumentData -m > /dev/null
	slay -f devf-s3c2400-p3
	devf-s3c2400-p3 -r -u2 -b5 -i 1,0
	waitfor /dev/fs1
   
	echo "restore files at /instrumentData"
	cp -R  /tmpInstrumentData/* /instrumentData


	#create a symbolic link from /log and /extendedLog to instrumentData.
	#so that software update finds the file swVersion to be updated.
	#NB! This is also done in ifs.build as symbolic links are not persistent.
	echo "Setting symbolic links /log and /extendedLog to /instrumentData"
	ln -Ps /instrumentData /log
	ln -Ps /instrumentData /extendedLog


	#create a flag
	echo "create a flag"
	touch $FLAG_FILE
	
	return $retVal
}


########################### SCRIPT ENTRY POINT ##################################
#
# This is where the script starts. 
# Returns 0 if success.
#
#################################################################################
echo "Flash repartition script started"
success=0

flashrepartition

if [ "$?" != "0" ]
then
	success=-1
	echo "Flash repartition failed!"
else
	echo "Flash repartition success!"
fi

echo $success
echo "Flash repartition script done!"
exit $success

