#!/bin/sh

#Global constant declarations
g_filename="AS100#"
g_deletepattern="*patientrecfile.bin"

root="/"

g_totalsize=0

############################ CREATE FILENAME ####################################
#
# Puts together the filename based on instrument ID and date, which is stored in 
# global var filename
#
#################################################################################
createfilename () {

	read_id=$(/proc/boot/real-calib_arm e)
	instr_id=${read_id#"serial number = "}
	date_id=$(date +%Y%m%d-%H.%M.%S)

	g_dirname=${g_filename}${instr_id}-${date_id}
}


################ Delete files from tar archive ####################
#
# Takes a list of files to delete from the new tar archive g_dirname as argument
#
#################################################################################
DeleteFromTar () {

	for i in $@; do
		echo Deleting $i from tar archive
		tar --delete -f ${g_dirname}.tar $i
	done

}

############################ BACK UP LOGFILES ####################################
#
# Creates a tarball out of the files to be backed up. Then zip it and add it to 
# file15 on MSD. A temporary folder on MSD is used.
#
#################################################################################
logfilebackup () {
	
	
	# Create temporary folder for file operations
	rm -Rf /usbdongle/tmp
	mkdir /usbdongle/tmp
	
	#Sets the glogal variable filename to date and device based name
	createfilename

	#Go to the work directory and tar together the files and dirs to one file
	cd /usbdongle/tmp
	for backupfiles in $@; do
		tar -uvf ${g_dirname}.tar $backupfiles > /dev/null
	done

	# Remove the patient log from the newly created tar archive
	delfiles=$(tar -tf ${g_dirname}.tar ${g_deletepattern})
	DeleteFromTar $delfiles

	# zip the tar file to save space and add it to file15 on MSD
	gzip ${g_dirname}.tar
	tar -uvf ../file15 ${g_dirname}.tar.gz

	# Remove temporary folder
	rm -Rf /usbdongle/tmp
	cd ${root}	
}


########################### SCRIPT ENTRY POINT ##################################
#
# This is where the script starts. 
#
#################################################################################

logfilebackup $@

